@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: error.c,v 1.11 2004/04/08 11:14:02 ats Exp $
+ * $Id: error.c,v 1.15 2004/07/18 20:44:01 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,6 +26,8 @@
 #endif
 
 #include <stdlib.h>
+#include <string.h>
+#include <errno.h>
 
 #include "statgrab.h"
 #include "tools.h"
@@ -33,8 +35,10 @@
 static sg_error error = SG_ERROR_NONE;
 #define ERROR_ARG_MAX 256
 static char error_arg[ERROR_ARG_MAX];
+static int errno_value = 0;
 
 void sg_set_error(sg_error code, const char *arg) {
+	errno_value = 0;
 	error = code;
 	if (arg != NULL) {
 		sg_strlcpy(error_arg, arg, sizeof error_arg);
@@ -45,6 +49,11 @@ void sg_set_error(sg_error code, const char *arg) {
 	}
 }
 
+void sg_set_error_with_errno(sg_error code, const char *arg) {
+	sg_set_error(code, arg);
+	errno_value = errno;
+}
+
 sg_error sg_get_error() {
 	return error;
 }
@@ -53,6 +62,10 @@ const char *sg_get_error_arg() {
 	return error_arg;
 }
 
+int sg_get_error_errno() {
+	return errno_value;
+}
+
 const char *sg_str_error(sg_error code) {
 	switch (code) {
 	case SG_ERROR_NONE:
