@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: process_stats.c,v 1.72 2004/04/08 23:30:29 ats Exp $
+ * $Id: process_stats.c,v 1.74 2004/07/18 21:30:11 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -131,7 +131,7 @@ sg_process_stats *sg_get_process_stats(int *entries){
 
 #ifdef LINUX
 	if ((f=fopen("/proc/uptime", "r")) == NULL) {
-		sg_set_error(SG_ERROR_OPEN, "/proc/uptime");
+		sg_set_error_with_errno(SG_ERROR_OPEN, "/proc/uptime");
 		return NULL;
 	}
 	if((fscanf(f,"%lu %*d",&uptime)) != 1){
@@ -142,7 +142,7 @@ sg_process_stats *sg_get_process_stats(int *entries){
 #endif
 
 	if((proc_dir=opendir(PROC_LOCATION))==NULL){
-		sg_set_error(SG_ERROR_OPENDIR, PROC_LOCATION);
+		sg_set_error_with_errno(SG_ERROR_OPENDIR, PROC_LOCATION);
 		return NULL;
 	}
 
@@ -307,7 +307,8 @@ sg_process_stats *sg_get_process_stats(int *entries){
 	mib[2] = KERN_PROC_ALL;
 
 	if(sysctl(mib, 3, NULL, &size, NULL, 0) < 0) {
-		sg_set_error(SG_ERROR_SYSCTL, "CTL_KERN.KERN_PROC.KERN_PROC_ALL");
+		sg_set_error_with_errno(SG_ERROR_SYSCTL,
+		                        "CTL_KERN.KERN_PROC.KERN_PROC_ALL");
 		return NULL;
 	}
 
@@ -320,7 +321,8 @@ sg_process_stats *sg_get_process_stats(int *entries){
 	memset(kp_stats, 0, size);
 
 	if(sysctl(mib, 3, kp_stats, &size, NULL, 0) < 0) {
-		sg_set_error(SG_ERROR_SYSCTL, "CTL_KERN.KERN_PROC.KERN_PROC_ALL");
+		sg_set_error_with_errno(SG_ERROR_SYSCTL,
+		                        "CTL_KERN.KERN_PROC.KERN_PROC_ALL");
 		free(kp_stats);
 		return NULL;
 	}
@@ -546,7 +548,7 @@ sg_process_stats *sg_get_process_stats(int *entries){
 			mib[4] = 0;
 
 			if(sysctl(mib, 5, NULL, &size, NULL, 0) < 0) {
-				sg_set_error(SG_ERROR_SYSCTL, "CTL_KERN.KERN_LWP.pid.structsize.0");
+				sg_set_error_with_errno(SG_ERROR_SYSCTL, "CTL_KERN.KERN_LWP.pid.structsize.0");
 				return NULL;
 			}
 
@@ -559,7 +561,7 @@ sg_process_stats *sg_get_process_stats(int *entries){
 			}
 
 			if(sysctl(mib, 5, kl_stats, &size, NULL, 0) < 0) {
-				sg_set_error(SG_ERROR_SYSCTL, "CTL_KERN.KERN_LWP.pid.structsize.buffersize");
+				sg_set_error_with_errno(SG_ERROR_SYSCTL, "CTL_KERN.KERN_LWP.pid.structsize.buffersize");
 				return NULL;
 			}
 		}
@@ -601,6 +603,8 @@ sg_process_stats *sg_get_process_stats(int *entries){
 			proc_state_ptr->state = SG_PROCESS_STATE_UNKNOWN;
 			break;
 		}
+
+		free(kl_stats);
 #else
 #ifdef FREEBSD5
 		switch (kp_stats[i].ki_stat) {
