@@ -18,9 +18,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: statgrab.h,v 1.49 2004/04/08 13:44:44 ats Exp $
+ * $Id: statgrab.h,v 1.53 2004/07/18 20:44:01 ats Exp $
  */
 
+#ifndef STATGRAB_H
+#define STATGRAB_H
+
 #include <sys/types.h>
 
 /* FIXME typedefs for 32/64-bit types */
@@ -64,8 +67,10 @@ typedef enum {
 } sg_error;
 
 void sg_set_error(sg_error code, const char *arg);
+void sg_set_error_with_errno(sg_error code, const char *arg);
 sg_error sg_get_error();
 const char *sg_get_error_arg();
+int sg_get_error_errno();
 const char *sg_str_error(sg_error code);
 
 typedef struct {
@@ -263,3 +268,4 @@ sg_process_count *sg_get_process_count();
 #include <statgrab_deprecated.h>
 #endif
 
+#endif
