@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: tools.c,v 1.52 2004/04/08 10:56:13 tdb Exp $
+ * $Id: tools.c,v 1.56 2004/07/18 21:30:12 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -481,7 +481,7 @@ struct uvmexp *sg_get_uvmexp() {
 	mib[1] = VM_UVMEXP;
 
 	if (sysctl(mib, 2, &uvm, &size, NULL, 0) < 0) {
-		sg_set_error(SG_ERROR_SYSCTL, "CTL_VM.VM_UVMEXP");
+		sg_set_error_with_errno(SG_ERROR_SYSCTL, "CTL_VM.VM_UVMEXP");
 		return NULL;
 	}
 
@@ -490,6 +490,8 @@ struct uvmexp *sg_get_uvmexp() {
 #endif
 
 int sg_init(){
+	sg_set_error(SG_ERROR_NONE, NULL);
+
 #if (defined(FREEBSD) && !defined(FREEBSD5)) || defined(DFBSD)
 	if (sg_get_kvm() == NULL) {
 		return -1;
@@ -512,11 +514,11 @@ int sg_init(){
 
 int sg_drop_privileges() {
 	if (setegid(getgid()) != 0) {
-		sg_set_error(SG_ERROR_SETEGID, NULL);
+		sg_set_error_with_errno(SG_ERROR_SETEGID, NULL);
 		return -1;
 	}
 	if (seteuid(getuid()) != 0) {
-		sg_set_error(SG_ERROR_SETEUID, NULL);
+		sg_set_error_with_errno(SG_ERROR_SETEUID, NULL);
 		return -1;
 	}
 	return 0;
@@ -526,7 +528,7 @@ void *sg_realloc(void *ptr, size_t size) {
 	void *tmp = NULL;
 	tmp = realloc(ptr, size);
 	if(tmp == NULL) {
-		sg_set_error(SG_ERROR_MALLOC, NULL);
+		sg_set_error_with_errno(SG_ERROR_MALLOC, NULL);
 	}
 	return tmp;
 }
