@@ -1,5 +1,5 @@
 /*
- * i-scream central monitoring system
+ * i-scream libstatgrab
  * http://www.i-scream.org
  * Copyright (C) 2000-2004 i-scream
  * 
@@ -18,11 +18,13 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: tools.h,v 1.15 2004/02/16 14:55:32 tdb Exp $
+ * $Id: tools.h,v 1.24 2004/04/08 10:56:13 tdb Exp $
  */
 
 #include <stdio.h>
+#if defined(LINUX) || defined(CYGWIN)
 #include <regex.h>
+#endif
 #if defined(FREEBSD) || defined(DFBSD)
 #include <kvm.h>
 #endif
@@ -30,29 +32,31 @@
 #include <uvm/uvm_extern.h>
 #endif
 
-#ifndef HAVE_ATOLL
-static long long atoll(const char *s);
+#ifdef SOLARIS
+const char *sg_get_svr_from_bsd(const char *bsd);
 #endif
 
-#ifndef HAVE_STRLCPY
-size_t strlcat(char *dst, const char *src, size_t siz);
+size_t sg_strlcat(char *dst, const char *src, size_t siz);
+size_t sg_strlcpy(char *dst, const char *src, size_t siz);
+
+int sg_update_string(char **dest, const char *src);
+
+#if defined(LINUX) || defined(CYGWIN)
+long long sg_get_ll_match(char *line, regmatch_t *match);
+char *sg_get_string_match(char *line, regmatch_t *match);
+
+char *sg_f_read_line(FILE *f, const char *string);
 #endif
 
-#ifndef HAVE_STRLCPY
-size_t strlcpy(char *dst, const char *src, size_t siz);
-#endif
-
-long long get_ll_match(char *line, regmatch_t *match);
-
-char *f_read_line(FILE *f, const char *string);
-
-char *get_string_match(char *line, regmatch_t *match);
-
-#if defined(FREEBSD) || defined(DFBSD)
-kvm_t *get_kvm(void);
+#if (defined(FREEBSD) && !defined(FREEBSD5)) || defined(DFBSD)
+kvm_t *sg_get_kvm(void);
+kvm_t *sg_get_kvm2(void);
 #endif
 
 #if defined(NETBSD) || defined(OPENBSD)
-struct uvmexp *get_uvmexp(void);
+struct uvmexp *sg_get_uvmexp(void);
 #endif
 
+void *sg_realloc(void *ptr, size_t size);
+#define sg_malloc(size) sg_realloc(NULL, size)
+
