@@ -18,7 +18,7 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
  * 02111-1307 USA
  *
- * $Id: user_stats.c,v 1.25 2004/04/07 21:08:40 tdb Exp $
+ * $Id: user_stats.c,v 1.26 2004/07/18 21:30:12 ats Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -75,7 +75,7 @@ sg_user_stats *sg_get_user_stats(){
 #endif
 #ifdef ALLBSD
 	if ((f=fopen(_PATH_UTMP, "r")) == NULL){
-		sg_set_error(SG_ERROR_OPEN, _PATH_UTMP);
+		sg_set_error_with_errno(SG_ERROR_OPEN, _PATH_UTMP);
 		return NULL;
 	}
 	while((fread(&entry, sizeof(entry),1,f)) != 0){
